@@ -1,4 +1,4 @@
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 
 #Copyright (C) Fiz Vazquez vud1@sindominio.net
 # Modified by dgranda
@@ -22,6 +22,8 @@ import os
 import traceback
 from lxml import etree
 from pytrainer.lib.date import getDateTime
+from pytrainer.core.activity import Activity
+from sqlalchemy.orm import exc
 
 class gpxplus():
 	def __init__(self, parent = None, data_path = None):
@@ -81,9 +83,10 @@ class gpxplus():
 		if time is None:
 			return False
 		time = time[0].strftime("%Y-%m-%dT%H:%M:%SZ")
-		if self.parent.parent.ddbb.select("records","*","date_time_utc=\"%s\"" % (time)):
+		try:
+			self.parent.parent.ddbb.session.query(Activity).filter(Activity.date_time_utc == time).one()
 			return True
-		else:
+		except exc.NoResultFound:
 			return False
 
 	def getDetails(self, tree, startTime):
