@@ -24,7 +24,6 @@ from dateutil.tz import tzlocal
 
 from pytrainer.lib.date import second2time
 from pytrainer.lib.gpx import Gpx
-from pytrainer.lib.graphdata import GraphData
 from pytrainer.environment import Environment
 from pytrainer.lib import uc
 from pytrainer.profile import Profile
@@ -109,7 +108,9 @@ class ActivityService(object):
         else:
             logging.debug("Activity NOT found in pool")
             self.pool[sid] = self.pytrainer_main.ddbb.session.query(Activity).options(
-                joinedload('sport'), joinedload('equipment'), joinedload('Laps')
+                joinedload(Activity.sport),
+                joinedload(Activity.equipment),
+                joinedload(Activity.Laps)
             ).filter(Activity.id == id).one()
             self.pool_queue.append(sid)
         if len(self.pool_queue) > self.max_size:
@@ -138,9 +139,9 @@ class ActivityService(object):
     def get_activities_for_day(self, date, sport=None):
         """Iterates the activities for a specific date, optionally restricted by Sport)"""
         if not sport:
-            activities = self.pytrainer_main.ddbb.session.query(Activity).filter(Activity.date == date).options(joinedload('Laps'))
+            activities = self.pytrainer_main.ddbb.session.query(Activity).filter(Activity.date == date).options(joinedload(Activity.Laps))
         else:
-            activities = self.pytrainer_main.ddbb.session.query(Activity).filter(and_(Activity.date == date, Activity.sport == sport)).options(joinedload('Laps'))
+            activities = self.pytrainer_main.ddbb.session.query(Activity).filter(and_(Activity.date == date, Activity.sport == sport)).options(joinedload(Activity.Laps))
         for activity in activities:
             sid = str(activity.id)
             if sid in self.pool:
@@ -440,6 +441,7 @@ tracks (%s)
         return self.sport.name
 
     def _generate_per_lap_graphs(self):
+        from pytrainer.lib.graphdata import GraphData
         '''Build lap based graphs...'''
         logging.debug(">>")
         if self.laps is None:
@@ -499,6 +501,7 @@ tracks (%s)
         logging.debug("<<")
 
     def _init_graph_data(self):
+        from pytrainer.lib.graphdata import GraphData
         logging.debug(">>")
         if self.tracklist is None:
             logging.debug("No tracklist in activity")
