@@ -3,9 +3,8 @@
 from .SimpleGladeApp import SimpleBuilderApp
 from gi.repository import Gtk
 from gi.repository import GObject
-import os, glob, sys
+import os
 import logging
-import types
 import csv
 import locale
 
@@ -14,6 +13,7 @@ from pytrainer.gui.dialogs import fileChooserDialog
 from pytrainer.lib.date import getDateTime
 from pytrainer.core.activity import Activity
 from pytrainer.lib.localization import gtk_str
+from pytrainer.importdata import iterate_import_tools
 
 
 class WindowImportdata(SimpleBuilderApp):
@@ -202,21 +202,9 @@ class WindowImportdata(SimpleBuilderApp):
         #Remove all components in vbox - in case of re-detection
         for child in self.vboxImportTools.get_children():
             self.vboxImportTools.remove(child)
-        #Get import tool_* files
-        fileList = glob.glob(self.data_path+"imports/tool_*.py")
-        logging.debug("Tools filelist: %s" % fileList)
-        for toolFile in fileList:
-            index = fileList.index(toolFile)
-            directory, filename = os.path.split(toolFile)
-            filename = filename.rstrip('.py')
-            classname = filename.lstrip('tool_')
-            #Import module
-            sys.path.insert(0, os.path.join(self.data_path, "imports"))
-            module = __import__(filename)
-            toolMain = getattr(module, classname)
-            #Instantiate module
-            toolClass = toolMain(self.parent, self.data_path)
-            #Get info from class
+        # Get import tool_* files
+        for toolClass in iterate_import_tools(self.parent):
+            # Get info from class
             toolName = toolClass.getName()
             toolTable = Gtk.Table()
             toolFrame = Gtk.Frame(label=toolName)
@@ -258,21 +246,8 @@ class WindowImportdata(SimpleBuilderApp):
         '''
         logging.debug('>>')
         self.updateStatusbar(self.statusbarImportFile, _("Checking file type for: ") + import_filename)
-        #Get imports files_* files
-        fileList = glob.glob(self.data_path+"imports/file_*.py")
-        fileList.sort()
-        logging.debug("File filelist: %s" % fileList)
-        for processingFile in fileList:
-            directory, filename = os.path.split(processingFile)
-            filename = filename.rstrip('.py')
-            logging.debug("Trying: %s" % filename)
-            classname = filename.lstrip('file_')
-            #Import module
-            sys.path.insert(0, self.data_path + "imports")
-            module = __import__(filename)
-            processMain = getattr(module, classname)
-            #Instantiate module
-            processClass = processMain(self.parent, self.data_path)
+        # Get imports files_* files
+        for processClass in iterate_import_tools(self.parent):
             isValid = processClass.testFile(import_filename)
             if isValid:
                 logging.debug('<<')
