@@ -42,33 +42,35 @@ class ActivityTest(unittest.TestCase):
         self.uc.set_us(False)
         self.service = ActivityService(pytrainer_main=main)
         records_table = DeclarativeBase.metadata.tables['records']
-        self.ddbb.session.execute(records_table.insert({'distance': 46.18,
-                                                            'maxspeed': 44.6695617695,
-                                                            'maxpace': 1.2,
-                                                            'title': u'test activity',
-                                                            'unegative': 564.08076273,
-                                                            'upositive': 553.05993673,
-                                                            'average': 22.3882142185,
-                                                            'date_time_local': u'2016-07-24 12:58:23+0300',
-                                                            'calories': 1462,
-                                                            'beats': 115.0,
-                                                            'comments': u'test comment',
-                                                            'pace': 2.4,
-                                                            'date_time_utc': u'2016-07-24T09:58:23Z',
-                                                            'date': datetime.date(2016, 7, 24),
-                                                            'duration': 7426,
-                                                            'sport': 1,
-                                                            'maxbeats': 120.0}))
+        self.ddbb.session.execute(records_table.insert(), {
+            'distance': 46.18,
+            'maxspeed': 44.6695617695,
+            'maxpace': 1.2,
+            'title': 'test activity',
+            'unegative': 564.08076273,
+            'upositive': 553.05993673,
+            'average': 22.3882142185,
+            'date_time_local': '2016-07-24 12:58:23+0300',
+            'calories': 1462,
+            'beats': 115.0,
+            'comments': 'test comment',
+            'pace': 2.4,
+            'date_time_utc': '2016-07-24T09:58:23Z',
+            'date': datetime.date(2016, 7, 24),
+            'duration': 7426,
+            'sport': 1,
+            'maxbeats': 120.0})
         laps_table = DeclarativeBase.metadata.tables['laps']
-        self.ddbb.session.execute(laps_table.insert({'distance': 46181.9,
-                                                     'lap_number': 0,
-                                                     'calories': 1462,
-                                                         'elapsed_time': u'7426.0',
-                                                         'record': 1,
-                                                         'intensity': u'active',
-                                                         'avg_hr': 136,
-                                                         'max_hr': 173,
-                                                         'laptrigger': u'manual'}))
+        self.ddbb.session.execute(laps_table.insert(), {
+            'distance': 46181.9,
+            'lap_number': 0,
+            'calories': 1462,
+            'elapsed_time': '7426.0',
+            'record': 1,
+            'intensity': 'active',
+            'avg_hr': 136,
+            'max_hr': 173,
+            'laptrigger': 'manual'})
         self.activity = self.service.get_activity(1)
 
     def tearDown(self):
@@ -95,7 +97,7 @@ class ActivityTest(unittest.TestCase):
         self.assertEqual(self.activity.time, self.activity.duration)
 
     def test_activity_starttime(self):
-        self.assertEqual(self.activity.starttime, '12:58:23 PM')
+        self.assertEqual(self.activity.starttime, '12:58:23')
 
     def test_activity_time_tuple(self):
         self.assertEqual(self.activity.time_tuple, (2, 3, 46))
