@@ -10,9 +10,13 @@ try:
 except ImportError:
     from mock import Mock
 import os
+import sys
 from lxml import etree
-from imports.file_garminfit import garminfit
+
+from pytrainer.environment import Environment
 from pytrainer.lib.ddbb import DDBB
+from pytrainer.importdata import import_plugin_class
+
 
 class GarminFitTest(unittest.TestCase):
 
@@ -20,6 +24,7 @@ class GarminFitTest(unittest.TestCase):
         self.ddbb = DDBB()
         self.ddbb.connect()
         self.ddbb.create_tables(add_default=True)
+        self.environment = Environment()
         self.parent = Mock()
         self.parent.parent = Mock()
         self.parent.parent.ddbb = self.ddbb
@@ -31,9 +36,9 @@ class GarminFitTest(unittest.TestCase):
     def test_parse_fit_file(self):
         try:
             current_path = os.path.dirname(os.path.abspath(__file__))
-            data_path = os.path.dirname(os.path.dirname(os.path.dirname(current_path))) + "/"
             fit_file = current_path + "/sample.fit"
-            garmin_fit = garminfit(self.parent, data_path)
+            sys.path.insert(0, os.path.join(self.environment.data_path, "imports"))
+            garmin_fit = import_plugin_class(self.environment, self.parent, "file_garminfit.py")
             xmldoc = etree.fromstring(garmin_fit.fromFIT2TCXv2(fit_file))
             valid_xml = garmin_fit.validate(xmldoc, "schemas/GarminTrainingCenterDatabase_v2.xsd")
             self.assertTrue(valid_xml)
